@@ -1,5 +1,4 @@
 #!/usr/bin/perl
-################################################################################
 
 ### Scenario 1: Extending an Object with Module Methods
 
@@ -20,8 +19,6 @@
         print "$key: ", $self->{$key} // 'undefined', "\n";
     }
 
-    ############################################################################
-
     package MyObject;
 
     sub new {
@@ -30,8 +27,6 @@
         return $self;
     }
 
-    ############################################################################
-
     package main;
 
     use strict;
@@ -62,8 +57,6 @@
         return $self;
     }
 
-    ############################################################################
-
     package main;
 
     use Extender;
@@ -101,8 +94,6 @@
         print "Value: $$self\n";
     }
 
-    ############################################################################
-
     package MyClass1;
 
     sub new {
@@ -111,8 +102,6 @@
         return $self;
     }
 
-    ############################################################################
-
     package MyClass2;
 
     sub new {
@@ -121,8 +110,6 @@
         return $self;
     }
 
-    ############################################################################
-
     package main;
 
     use strict;
@@ -156,8 +143,6 @@
 
 ### Scenario 4: Adding Methods to Raw References (Hash, Array, Scalar)
 
-    ############################################################################
-
     # PACKAGES
 
     package HashMethods;
@@ -179,8 +164,6 @@
 
     1;
 
-    ############################################################################
-
     package ArrayMethods;
 
     use strict;
@@ -200,8 +183,6 @@
 
     1;
 
-    ############################################################################
-
     package ScalarMethods;
 
     use strict;
@@ -231,8 +212,6 @@
 
     1;
 
-    ############################################################################
-
     # MAIN 
 
     package main;
@@ -305,8 +284,6 @@
 
     # Example methods to manipulate shared data
 
-    ############################################################################
-
     # Method to set data in a shared hash
     sub set_hash_data {
         my ($self, $key, $value) = @_;
@@ -321,8 +298,6 @@
         return $self->{$key};
     }
 
-    ############################################################################
-
     # Method to add item to a shared array
     sub add_array_item {
         my ($self, $item) = @_;
@@ -337,8 +312,6 @@
         return $self->[$index];
     }
 
-    ############################################################################
-
     # Method to set data in a shared scalar
     sub set_scalar_data {
         my ($self, $value) = @_;
@@ -353,8 +326,6 @@
         return ${$self};
     }
 
-    ############################################################################
-
     # Create shared data structures
     my %shared_hash :shared;
     my @shared_array :shared;
@@ -365,8 +336,6 @@
     my $shared_array_object = \@shared_array;
     my $shared_scalar_object = \$shared_scalar;
 
-    ############################################################################
-
     # Extend the shared hash object with custom methods
     Extends($shared_hash_object,
         set_hash_data => \&set_hash_data,
@@ -385,8 +354,6 @@
         get_scalar_data => \&get_scalar_data,
     );
 
-    ############################################################################
-
     # Create threads to manipulate shared objects concurrently
 
     # Thread for shared hash object
@@ -407,8 +374,6 @@
         print "Scalar thread: value = " . $shared_scalar_object->get_scalar_data() . "\n";
     });
 
-    ############################################################################
-
     # Wait for all threads to finish
     $hash_thread->join();
     $array_thread->join();
@@ -416,6 +381,34 @@
 
     1;
 
+# Override - The Override function replaces an existing method on an object with a new implementation.
+
+    package MyClass;
+
+    sub new {
+        my $class = shift;
+        my $self = bless {}, $class;
+        return $self;
+    }
+
+    sub existing_method {
+        return "Original method";
+    }
+
+    package main;
+
+    use Extender;
+
+    my $object = MyClass->new();
+
+    # Define a method with the same name as an existing method
+    Override($object, 'existing_method', sub { return "New method"; });
+
+    # Using the extended method
+    print $object->existing_method(), "\n";  # Outputs: New method
+
+    1;
+
 # Alias - The Alias function creates an alias for an existing method on an object.
 
     package MyClass;
@@ -430,8 +423,6 @@
         return "Original method";
     }
 
-    ############################################################################
-
     package main;
 
     use Extender;
@@ -464,8 +455,6 @@
         return "Method 2";
     }
 
-    ############################################################################
-
     package main;
 
     use Extender;
@@ -501,8 +490,6 @@
         return $self;
     }
 
-    ############################################################################
-
     package main;
 
     use Extender;
@@ -517,6 +504,40 @@
 
     1;
 
+# ConditionalExtend - The ConditionalExtend function conditionally extends an object with methods based on a boolean condition.
+
+    package MyClass;
+
+    sub new {
+        my $class = shift;
+        my $self = bless {}, $class;
+        return $self;
+    }
+
+    package main;
+
+    use Extender;
+
+    my $object1 = MyClass->new();
+    my $object2 = MyClass->new();
+
+    # Extend $object1 with methods based on condition
+    ConditionalExtend($object1, 1, 'HashMethods', 'set_value', 'get_value');
+
+    # Extend $object2 with methods based on condition
+    ConditionalExtend($object2, 0, 'HashMethods', 'set_value', 'get_value');
+
+    # Check if methods are available on $object1
+    print $object1->set_value('key', 'value'), "\n";  # Outputs: value
+
+    # Check if methods are available on $object2
+    eval {
+        $object2->set_value('key', 'value');
+    };
+    warn "Error: $@" if $@;  # Outputs: Error: Can't locate object method "set_value" via package
+
+    1;
+
 # Decorate - The Decorate function wraps an existing method on an object with additional behavior.
 
     package MyClass;
@@ -531,8 +552,6 @@
         return "Original method";
     }
 
-    ############################################################################
-
     package main;
 
     use Extender;
@@ -560,8 +579,6 @@
         *{$object . "::new_method"} = sub { return "New method"; };
     }
 
-    ############################################################################
-
     package MyClass;
 
     sub new {
@@ -570,8 +587,6 @@
         return $self;
     }
 
-    ############################################################################
-
     package main;
 
     use Extender;
@@ -588,227 +603,92 @@
 
 # InitHook - The InitHook function attaches initialization and destruction hooks to an object.
 
-    package TestObject;
-
-    sub new { return bless {}, shift }
-
-    sub DESTROY {
-        my $self = shift;
-        # Implement destruction logic if needed
-    }
-
-    ############################################################################
-
-    package main;
-
-    use Extender;
-
-    InitHook('TestObject', 'INIT', sub {
-        print "Initializing object\n";
-    });
-
-    InitHook('TestObject', 'DESTRUCT', sub {
-        print "Destructing object\n";
-    });
-
-    my $object = TestObject->new(); # Output: Initializing object
-    undef $object; # Output: Destructing object
-
-    1;
-
-# Creating Extender Class objects from any (even shared) reference typed variable except for CODE refrerences
-
-    package main;
-
-    use Extender;
-
-    my $object = Extend({},'Extender');
-    $object->Extends( method => sub { return "method"; } );
-    print $object->method(), "\n";  # Outputs: method
-
-    my $array = Extend([],'Extender');
-    $array->Extends( method => sub { return "method"; } );
-    print $array->method(), "\n";  # Outputs: method
-
-    my $scalar = Extend(\"",'Extender');
-    $scalar->Extends( method => sub { return "method"; } );
-    print $scalar->method(), "\n";  # Outputs: method
-
-    my $glob = Extend(\*GLOB,'Extender');
-    $glob->Extends( method => sub { return "method"; } );
-    print $glob->method(), "\n";  # Outputs: method
-
-    1;
-
-# Creating an STDERR Logger with decorative functionalities
-
-    use strict;
-    use warnings;
-    use Time::Piece;
-
-    ############################################################################
-    # BaseLogger.pm
-    package BaseLogger;
-    use strict;
-    use warnings;
+    package MyClass;
 
     sub new {
         my $class = shift;
-        return bless {}, $class;
+        my $self = bless {}, $class;
+        return $self;
     }
 
-    sub log {
-        my ($self, $message) = @_;
-        print STDERR $message;
-    }
-
-    1;
-
-    ############################################################################
-    # LoggerDecorators.pm
-    package LoggerDecorators;
-
-    use strict;
-    use warnings;
-    use Time::Piece;
-
-    # Timestamp decorator
-    sub add_timestamp {
-        my ($logger) = @_;
-        return sub {
-            my ($self, $message) = @_;
-            my $timestamp = localtime->strftime('%Y-%m-%d %H:%M:%S');
-            $logger->($self, "[$timestamp] $message");
-        };
-    }
-
-    # Log level decorator
-    sub add_log_level {
-        my ($logger, $level) = @_;
-        return sub {
-            my ($self, $message) = @_;
-            $logger->($self, "[$level] $message");
-        };
-    }
-
-    1;
-
-    ############################################################################
-    # Example.pl
-
     package main;
-    use strict;
-    use warnings;
-    use BaseLogger;
-    use LoggerDecorators;
 
-    # Create an instance of BaseLogger
-    my $logger = BaseLogger->new();
-
-    # Create a decorated logger
-    my $decorated_logger = sub {
-        my ($self, $message) = @_;
-        $logger->log($message);
-    };
-
-    # Apply decorators to extend logging functionality
-    $decorated_logger = add_timestamp($decorated_logger);
-    $decorated_logger = add_log_level($decorated_logger, 'INFO');
-
-    # Helper function to capture STDERR output
-    sub capture_stderr {
-        my ($code) = @_;
-        my $output;
-        {
-            open my $stderr_backup, '>&', STDERR or die "Cannot backup STDERR: $!";
-            open STDERR, '>', \$output or die "Cannot redirect STDERR: $!";
-            
-            $code->();
-            
-            open STDERR, '>&', $stderr_backup or die "Cannot restore STDERR: $!";
-            close $stderr_backup;
-        }
-        return $output;
-    }
-
-    # Capture logging output
-    my $stderr_output = capture_stderr(sub {
-        $decorated_logger->("This is a test message\n");
-    });
-
-    # Output captured log
-    print "Captured STDERR output:\n";
-    print $stderr_output;
-
-    1;
-
-# Extending Decorating and Aliasing class objects
-
-    use strict;
-    use warnings;
     use Extender;
 
-    # Declare the class with a namespace and version ###########################
-    class MyApp::Logger 1.0 {
+    my $object = MyClass->new();
 
-        # Constructor method
-        method new {
-            my $class = shift;
-            return bless {}, $class;
-        }
+    # Initialization hook
+    InitHook($object, 'INIT', sub {
+        print "Initializing object\n";
+    });
 
-        # Method with attributes
-        method log : Private {
-            my ($self, $message) = @_;
-            print STDERR $message;
-        }
+    # Destruction hook
+    InitHook($object, 'DESTRUCT', sub {
+        print "Destructing object\n";
+    });
 
-        # Public method to log an info message
-        method log_info {
-            my ($self, $message) = @_;
-            $self->log("[INFO] $message\n");
-        }
+    # Creating an instance triggers INIT hook
+    my $object2 = MyClass->new();  # Outputs: Initializing object
 
-        # Public method to log an error message
-        method log_error {
-            my ($self, $message) = @_;
-            $self->log("[ERROR] $message\n");
-        }
+    # Destroying an instance triggers DESTRUCT hook
+    undef $object2;  # Outputs: Destructing object
 
+    1;
+
+# GenerateMethod - The GenerateMethod function dynamically generates a method on an object.
+
+    package MyClass;
+
+    sub new {
+        my $class = shift;
+        my $self = bless {}, $class;
+        return $self;
     }
 
-    # Usage example
     package main;
 
-    # Create a new Logger object ###############################################
-    my $logger = Extend(
-        MyApp::Logger->new(),
-        'Extender'
-    )
-        ->Extends(
-            'log_warn', sub {
-                my ($self, $message) = @_;
-                $self->log("[WARN] $message\n");
-            }
-        )
-        ->Alias(
-            'log_error', 'log_err'
-        )
-        ->Decorate(
-            'log_info', 
-            sub {
-                my ($self, $original, @args) = @_;
-                # Add extra behavior before and after
-                my $result = $original->($self, @args);
-                $self->log("[DECORATED] $args[0]\n");
-                return $result;
-            }
-        );
+    use Extender;
 
-    # Use the extended functionalities
-    $logger->log_info("This is an informational message.");
-    $logger->log_warn("This is a warning message.");
-    $logger->log_err("This is an error message.");
+    my $object = MyClass->new();
 
-    # Testing the decorated method
-    $logger->log_info("This message is decorated.");
+    # Generate a dynamic method 'dynamic_method'
+    GenerateMethod($object, 'dynamic_method', sub {
+        my ($self, $arg1, $arg2) = @_;
+        return "Dynamic method called with args: $arg1, $arg2";
+    });
+
+    # Using the generated method
+    print $object->dynamic_method('arg1', 'arg2'), "\n";  # Outputs: Dynamic method called with args: arg1, arg2
+
+    1;
+
+# MooseCompat - The MooseCompat function applies methods from a Moose role package to an object.
+
+    package MooseX::Role::Parameterized::Extender::TestRole;
+    sub apply {
+        my ($class, $object) = @_;
+        no strict 'refs';
+        *{$object . "::new_method"} = sub { return "New method"; };
+    }
+
+    package MyClass;
+
+    sub new {
+        my $class = shift;
+        my $self = bless {}, $class;
+        return $self;
+    }
+
+    package main;
+
+    use Extender;
+
+    my $object = MyClass->new();
+
+    # Apply Moose role 'TestRole' to $object
+    MooseCompat($object, 'TestRole');
+
+    # Using the applied method
+    print $object->new_method(), "\n";  # Outputs: New method
+
+    1;
